==> unirest-java-2.3.10-sources.jar: kong/unirest/BasicResponse.java <==
/**
 * The MIT License
 *
 * Copyright for portions of unirest-java are held by Kong Inc (c) 2013.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package kong.unirest;

public class BasicResponse<T> extends BaseResponse<T> {
    private final T body;

    public BasicResponse(RawResponse httpResponse, T body) {
        super(httpResponse);
        this.body = body;
    }

    public BasicResponse(RawResponse httpResponse, String ogBody, RuntimeException ex) {
        this(httpResponse, null);
        setParsingException(ogBody, ex);
    }

    @Override
    public T getBody() {
        return body;
    }
}

==> unirest-java-3.13.10-sources.jar: kong/unirest/BasicResponse.java <==
/**
 * The MIT License
 *
 * Copyright for portions of unirest-java are held by Kong Inc (c) 2013.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */

package kong.unirest;

public class BasicResponse<T> extends BaseResponse<T> {
    private final T body;

    BasicResponse(BaseResponse response, T body) {
        super(response);
        this.body = body;
    }

    public BasicResponse(RawResponse httpResponse, T body) {
        super(httpResponse);
        this.body = body;
    }

    public BasicResponse(RawResponse httpResponse) {
        super(httpResponse);
        this.body = null;
    }

    public BasicResponse(RawResponse httpResponse, String ogBody, RuntimeException ex) {
        this(httpResponse, null);
        setParsingException(ogBody, ex);
    }

    @Override
    public T getBody() {
        return body;
    }

    @Override
    protected String getRawBody() {
        return null;
    }
}
